==> tea_9.0.orig.tar.gz: tea-9.0/src/interface.h <==
/***************************************************************************
                          interface.h  -  description
                             -------------------
    begin                : Mon Dec 1 2003
    copyright            : (C) 2003, 2004, 2005 by Peter 'Roxton' Semiletov
    email                : tea@list.ru
 ***************************************************************************/

GtkWidget *sr_wnd;
GtkWidget *tea_main_window;
GtkWidget *mainvbox;
GtkWidget *ent_search;
GtkWidget *dlg_colorsel;
GtkNotebook *notebook1;
GtkWidget *menubar1;
GtkWidget *mni_file_menu;
GtkWidget *mni_file_configs_menu;
GtkWidget *mni_autocomp;
GtkWidget *mni_ide;
GtkWidget *mni_ide_menu;
GtkWidget *mni_view_menu;
GtkWidget *mni_recent_list;
GtkWidget *mni_recent_menu;
GtkWidget *mni_sessions;
GtkWidget *mni_sessions_menu;
GtkWidget *mni_templates;
GtkWidget *mni_templates_menu;
GtkWidget *mni_latex;
GtkWidget *mni_latex_menu;
GtkWidget *mni_wiki_menu;
GtkWidget *mni_latex_menu;
GtkWidget *mni_docbook_menu;
GtkWidget *mni_list_menu;
GtkWidget *mni_morse_menu;
GtkVPaned *vpaned1;
GtkWidget *vbox2;
GtkWidget *scrolledwindow3;
GtkWidget *tv_logmemo;
GtkTextBuffer *log_memo_textbuffer;
GtkWidget *mni_edit_menu;
GtkWidget *mni_edit_undo;
GtkWidget *mni_edit_redo;
GtkWidget *mni_hl_mode_menu;
GtkWidget *mni_markup_menu;
GtkWidget *mni_insert_doctype_menu;
GtkWidget *mni_insert_char_entities_menu;
GtkWidget *mni_format_menu;
GtkWidget *mni_quest_menu;
GtkWidget *mni_ins_menu;
GtkWidget *mni_eol_menu;
GtkWidget *mni_savedifferent_menu;
GtkWidget *mni_opendifferent_menu;
GtkWidget *mni_markup_header_menu;
GtkWidget *mni_markup_header_item;
GtkWidget *mni_markup_align;
GtkWidget *mni_markup_align_menu;
GtkWidget *mni_what_menu;
GtkWidget *mni_functions;
GtkWidget *mni_spellcheck_menu;
GtkWidget *mni_spellcheck;
GtkWidget *mni_user_menu_menu;
GtkWidget *mni_user_menu;

  GtkWidget *mni_table_menu;
  GtkWidget *mni_functions_menu;
  GtkWidget *mni_functions_case;
  GtkWidget *mni_functions_case_menu;
  GtkWidget *mni_filter_menu;
  GtkWidget *mni_functions_number;
  GtkWidget *mni_functions_number_menu;
  GtkWidget *mni_functions_string;
  GtkWidget *mni_functions_string_menu;

  GtkWidget *mni_snippets_menu;
  GtkWidget *mni_snippets;
 
  GtkWidget *mni_html_menu;
  GtkWidget *mni_align_menu;

  GtkWidget *mni_co_menu;
  GtkWidget *mni_co;

  GtkWidget *mni_mm_menu;



  GtkWidget *mni_bro_menu;

  GtkWidget *mni_links;
  GtkMenuItem *mni_links_menu;

  GtkWidget *mni_sort_menu;

  GtkWidget *mni_tabs;
  GtkWidget *mni_tabs_menu;


  GtkWidget *mni_utils_menu;
  GtkWidget *mni_utils_cc_menu;

  GtkWidget *mni_utils_unitaz_menu;


GtkWidget *mni_bookmarks_root;
GtkWidget *mni_bookmarks_menu;
GtkWidget *mni_bookmarks_cc_menu;
GtkWidget *mni_view_menu;
GtkWidget *mni_add_to;

GtkWidget *tb_main_toolbar;

GtkWidget *mni_nav_menu;

GtkWidget *statusbar1;
GtkAccelGroup *accel_group;

GtkTextTag *temp_tag;

GtkTextTag *tag_lm_error;
GtkWidget *pb_status; 

guint id_mpb;      

GtkWidget* create_tea_main_window (void);
void statusbar_msg (const gchar *s);

void mpb_start (void);
void mpb_stop (void);

==> tea_11.0.orig.tar.gz: tea-11.0/src/interface.h <==
/***************************************************************************
                          interface.h  -  description
                             -------------------
    begin                : Mon Dec 1 2003
    copyright            : (C) 2003, 2004, 2005 by Peter 'Roxton' Semiletov
    email                : peter.semiletov@gmail.com
 ***************************************************************************/

GtkWidget *bt_close_current_doc;
GtkWidget *mni_suggestions;
GtkWidget *mni_ext_programs;
GtkWidget *sr_wnd;
GtkWidget *tea_main_window;
GtkWidget *mainvbox;
GtkWidget *ent_search;
GtkWidget *dlg_colorsel;
GtkNotebook *notebook1;
GtkWidget *menubar1;
GtkWidget *mni_file_menu;
GtkWidget *mni_mark_menu;

GtkWidget *mni_file_configs_menu;
GtkWidget *mni_autocomp;
GtkWidget *mni_ide;
GtkWidget *mni_ide_menu;
GtkWidget *mni_view_menu;
GtkWidget *mni_recent_list;
GtkWidget *mni_recent_menu;
GtkWidget *mni_sessions;
GtkWidget *mni_sessions_menu;
GtkWidget *mni_templates;
GtkWidget *mni_templates_menu;
GtkWidget *mni_latex;
GtkWidget *mni_latex_menu;
GtkWidget *mni_wiki_menu;
GtkWidget *mni_docbook_menu;
GtkWidget *mni_list_menu;
GtkWidget *mni_morse_menu;
GtkVPaned *vpaned1;
GtkWidget *vbox2;
GtkWidget *scrolledwindow3;
GtkWidget *tv_logmemo;
GtkTextBuffer *log_memo_textbuffer;
GtkWidget *mni_edit_menu;
GtkWidget *mni_edit_undo;
GtkWidget *mni_edit_redo;
GtkWidget *mni_hl_mode_menu;
GtkWidget *mni_markup_menu;
GtkWidget *mni_insert_doctype_menu;
GtkWidget *mni_insert_char_entities_menu;
GtkWidget *mni_format_menu;
GtkWidget *mni_quest_menu;
GtkWidget *mni_ins_menu;
GtkWidget *mni_eol_menu;
GtkWidget *mni_savedifferent_menu;
GtkWidget *mni_opendifferent_menu;
GtkWidget *mni_markup_header_menu;
GtkWidget *mni_markup_header_item;
GtkWidget *mni_markup_align;
GtkWidget *mni_markup_align_menu;
GtkWidget *mni_what_menu;
GtkWidget *mni_functions;
GtkWidget *mni_spellcheck_menu;
GtkWidget *mni_spellcheck;

  GtkWidget *mni_table_menu;
  GtkWidget *mni_functions_menu;
  GtkWidget *mni_functions_case;
  GtkWidget *mni_functions_case_menu;
  GtkWidget *mni_filter_menu;
  GtkWidget *mni_functions_number;
  GtkWidget *mni_functions_number_menu;
  GtkWidget *mni_functions_string;
  GtkWidget *mni_functions_string_menu;

  GtkWidget *mni_snippets_menu;
  GtkWidget *mni_snippets;
 
  GtkWidget *mni_html_menu;
  GtkWidget *mni_align_menu;

  GtkWidget *mni_co_menu;
  GtkWidget *mni_co;

  GtkWidget *mni_mm_menu;



  GtkWidget *mni_ext_programs_menu;

  GtkWidget *mni_links;
  GtkMenuItem *mni_links_menu;

  GtkWidget *mni_sort_menu;

  GtkWidget *mni_tabs;
  GtkWidget *mni_tabs_menu;


  GtkWidget *mni_utils_menu;
  GtkWidget *mni_utils_cc_menu;

  GtkWidget *mni_utils_unitaz_menu;


GtkWidget *mni_bookmarks_root;
GtkWidget *mni_bookmarks_menu;
GtkWidget *mni_bookmarks_cc_menu;
GtkWidget *mni_add_to;

GtkWidget *tb_main_toolbar;

GtkWidget *mni_nav_menu;

GtkWidget *statusbar1;
GtkAccelGroup *accel_group;

GtkTextTag *temp_tag;

GtkTextTag *tag_lm_error;
GtkWidget *pb_status; 

guint id_mpb;      

GtkWidget* create_tea_main_window (void);
void statusbar_msg (const gchar *s);

void mpb_start (void);
void mpb_stop (void);
void ui_update (void);
